;We define patterns at address $800 in VRAM.
;2 bytes define each 8x8 block (which is 2x2 'chunky pixels') 
;BUT... a different definition is used every 4 lines... so the full 8 bytes of each pattern are used.
;This allows us to make a pattern 'stripey' for some reason.

;We then select from those patterns as usual - one byte per tile using tilemap address $1400
;This means it will be effectively impossible to have full 16 color flexibility, 
;Since we have a choice of 256 tiles, our screen is limited to 256 'unique' color combinations,
;So 4 colors max for full flexible choice of colors (8 bits)



;For Cartridge	
	org &4000				;Base Cart Address
	db "AB"					;Fixed Header
	dw ProgramStart 		;Pointer to start of program
	db 00,00,00,00,00,00	;Unused
	
	;Effectively Code starts at address &400A
	

VdpOut_Data equ &98			;For Data writes
VdpOut_Control equ &99		;For Reg settings /Selecting Dest addr in VRAM

ProgramStart:			;Program Code Starts Here

	;Set up our screen
	ld c,VdpOut_Control
	ld b,VDPScreenInitData_End-VDPScreenInitData
	ld hl,VDPScreenInitData
	otir	
	
	
	ld hl,&800		;Define Tiles 128+ (8 Bytes per tile)
	call VDP_SetWriteAddress
	
	ld hl,TestSprite		;Copy Tile pixel Data
	ld b,16					;Bytes
	otir					;C=VdpOut_Data
	
	ld hl,&1400		;Define Tiles 128+ (8 Bytes per tile)
	call VDP_SetWriteAddress
	
	ld a,1
	ld b,128
OutAgain:
	out (VdpOut_Data),a
	
	nop
	nop
	out (VdpOut_Data),a
	nop
	nop
	
	djnz OutAgain
	
	DI					;Can't RET on Cartridge
	Halt 	

	
	;Pattern Data
TestSprite:			
;Pattern 0
	db $F0,$0F			;4 colors Line 1/4
	db $E0,$0E			;4 colors Line 2/4
	db $D0,$0D			;4 colors Line 3/4
	db $C0,$0C			;4 colors Line 4/4
;Pattern 1
	db $12,$12			;4 colors Line 1/4
	db $12,$12			;4 colors Line 2/4
	db $12,$12			;4 colors Line 3/4
	db $12,$12			;4 colors Line 4/4

	

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

VDPScreenInitData:
	;	Value   ,Register
	db %00000000,128+0	;mode register #0
	db %11001011,128+1	;mode register #1
	db %00000101,128+2	;mode register #1
	db %10000000,128+3	;colour table (Unused)
	db %00000001,128+4	;pattern generator table ($800)
	db %00100000,128+5	;sprite attribute table ($1000)
	db %00000000,128+6	;sprite pattern generator table ($0000)
	db %11110000,128+7	;border colour/character colour at text mode
VDPScreenInitData_End:

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

VDP_SetWriteAddress:		;Set VRAM address next write will occur
	ld a, l
    out (VdpOut_Control), a	;Send L byte
    ld a, h
    or %01000000			;Set WRITE (0=read)
    out (VdpOut_Control), a	;Send H  byte
	
	ld c,VdpOut_Data		;Set C to data Write Addr
	ret            
	
	